Mixed-Up Code Questions
------------------------

.. selectquestion:: mixedupcode_turtles_1_sq
   :fromid: mixedupcode_turtles_1, mixedupcode_turtles_1_ac
   :toggle: 

.. selectquestion:: mixedupcode_turtles_2_sq
   :fromid: mixedupcode_turtles_2, mixedupcode_turtles_2_ac
   :toggle: 

.. selectquestion:: mixedupcode_turtles_3_sq
   :fromid: mixedupcode_turtles_3, mixedupcode_turtles_3_ac
   :toggle: 

.. selectquestion:: mixedupcode_turtles_4_sq
   :fromid: mixedupcode_turtles_4, mixedupcode_turtles_4_ac
   :toggle: 

.. selectquestion:: mixedupcode_turtles_5_sq
   :fromid: mixedupcode_turtles_5, mixedupcode_turtles_5_ac
   :toggle: 

.. selectquestion:: mixedupcode_turtles_6_sq
   :fromid: mixedupcode_turtles_6, mixedupcode_turtles_6_ac
   :toggle: 

.. selectquestion:: mixedupcode_turtles_7_sq
   :fromid: mixedupcode_turtles_7, mixedupcode_turtles_7_ac
   :toggle: 

.. selectquestion:: mixedupcode_turtles_8_sq
   :fromid: mixedupcode_turtles_8, mixedupcode_turtles_8_ac
   :toggle: 

.. selectquestion:: mixedupcode_turtles_9_sq
   :fromid: mixedupcode_turtles_9, mixedupcode_turtles_9_ac
   :toggle: 

.. selectquestion:: mixedupcode_turtles_10_sq
   :fromid: mixedupcode_turtles_10, mixedupcode_turtles_10_ac
   :toggle: 